@@ -9,16 +9,16 @@ import subprocess
 from pyzm.helpers.Base import Base
 
 class AlprBase(Base):
-    def __init__(self, logger=None,options={}, alpr_options={}, url=None, apikey=None, tempdir='/tmp'):
+    def __init__(self, logger=None,options={}, tempdir='/tmp'):
         super().__init__(logger)
-        if not apikey:
+        if not options.get('alpr_key'):
             self.logger.Debug (1,'No API key specified, hopefully you do not need one')
-        self.apikey = apikey
+        self.apikey = options.get('alpr_key')
         #print (self.apikey)
         self.tempdir = tempdir
-        self.url = url
+        self.url = options.get('alpr_url')
         self.options = options
-        self.alpr_options = alpr_options
+        
 
     def setkey(self, key=None):
         self.apikey = key
@@ -36,7 +36,7 @@ class AlprBase(Base):
                 1,'Supplied object is not a file, assuming blob and creating file'
             )
             self.filename = self.tempdir + '/temp-plate-rec.jpg'
-            cv2.imwrite(filename, object)
+            cv2.imwrite(self.filename, object)
             self.remove_temp = True
         else:
             self.logger.Debug(1,f'supplied object is a file {object}')
@@ -67,25 +67,57 @@ class AlprBase(Base):
         return (xfactor, yfactor)
 
 
+class Alpr(AlprBase):
+    def __init__(self, options={},logger=None, tempdir='/tmp'):
+        """Wrapper class for all ALPR objects
+
+        Args:
+            options (dict, optional): Config options. Defaults to {}.
+            tempdir (str, optional): Path to store image for analysis. Defaults to '/tmp'.
+        """        
+        AlprBase.__init__(self, options=options,logger=logger, tempdir=tempdir)
+        self.alpr_obj = None
+
+        if self.options.get('alpr_service') == 'plate_recognizer':   
+            self.alpr_obj = PlateRecognizer(options=self.options)
+        elif self.options.get('alpr_service') == 'open_alpr':   
+            self.alpr_obj = OpenAlpr(options=self.options)
+        elif self.options.get('alpr_service') == 'open_alpr_cmline':   
+            self.alpr_obj = OpenAlprCmdLine(options=self.options)
+                  
+        else:
+            raise ValueError('ALPR service "{}" not known'.format(self.options.get('alpr_service')))
+
+    def detect(self, object):
+        return self.alpr_obj.detect(object)
+
+    def stats(self):
+        return self.alpr_obj.stats()
+
+
+
 class PlateRecognizer(AlprBase):
-    def __init__(self, url=None, apikey=None, options={}, alpr_options={}, tempdir='/tmp'):
+
+    def __init__(self, options={}, tempdir='/tmp'):
         """Wrapper class for platerecognizer.com
 
         Args:
-            url (string, optional): URL for service. Defaults to None.
-            apikey (string, optional): API key. Defaults to None.
             options (dict, optional): Config options. Defaults to {}.
-            alpr_options (dict, optional): Various ALPR options. Defaults to {}.
             tempdir (str, optional): Path to store image for analysis. Defaults to '/tmp'.
         """        
-        AlprBase.__init__(self, options=options,  alpr_options=alpr_options, url=url, apikey=apikey, tempdir=tempdir)
+        AlprBase.__init__(self, options=options,  tempdir=tempdir)
+        
+        url=self.options.get('alpr_url')
+        apikey=self.options.get('alpr_key')
+        
+        
         if not url:
             self.url = 'https://api.platerecognizer.com/v1'
 
         self.logger.Debug(
-            1,'PlateRecognizer ALPR initialized with options: {} and url: {}'.
-            format(alpr_options, self.url))
-        self.options = options
+            1,'PlateRecognizer ALPR initialized with url: {}'.
+            format(self.url))
+        
 
     def stats(self):
         """Returns API statistics
@@ -93,7 +125,7 @@ class PlateRecognizer(AlprBase):
         Returns:
             HTTP Response: HTTP response of statistics API
         """        
-        if self.alpr_options.get('alpr_api_type') != 'cloud':
+        if self.options.get('alpr_api_type') != 'cloud':
             self.logger.Debug (1,'local SDK does not provide stats')
             return {}
         try:
@@ -123,17 +155,16 @@ class PlateRecognizer(AlprBase):
         bbox = []
         labels = []
         confs = []
-        alpr_options = self.alpr_options
         self.prepare(object)
-        if alpr_options.get('stats') == 'yes':
+        if self.options.get('platerec_stats') == 'yes':
             self.logger.Debug(1,'Plate Recognizer API usage stats: {}'.format(
                 json.dumps(self.stats())))
         with open(self.filename, 'rb') as fp:
             try:
                 platerec_url = self.url
-                if self.alpr_options.get('alpr_api_type') == 'cloud':
+                if self.options.get('alpr_api_type') == 'cloud':
                     platerec_url += '/plate-reader'
-                payload = self.alpr_options.get('regions')
+                payload = self.options.get('platerec_regions')
                 response = requests.post(
                    platerec_url,
                     #self.url ,
@@ -157,15 +188,15 @@ class PlateRecognizer(AlprBase):
         (xfactor, yfactor) = self.getscale()
 
         if self.remove_temp:
-            os.remove(filename)
+            os.remove(self.filename)
 
         if response.get('results'):
             for plates in response.get('results'):
                 label = plates['plate']
                 dscore = plates['dscore']
                 score = plates['score']
-                if dscore >= alpr_options.get('min_dscore') and score >= alpr_options.get(
-                        'min_score'):
+                if dscore >= self.options.get('platerec_min_dscore') and score >= self.options.get(
+                        'platerec_min_score'):
                     x1 = round(int(plates['box']['xmin']) * xfactor)
                     y1 = round(int(plates['box']['ymin']) * yfactor)
                     x2 = round(int(plates['box']['xmax']) * xfactor)
@@ -176,33 +207,29 @@ class PlateRecognizer(AlprBase):
                 else:
                     self.logger.Debug(
                         1,'ALPR: discarding plate:{} because its dscore:{}/score:{} are not in range of configured dscore:{} score:{}'
-                        .format(label, dscore, score, alpr_options.get('min_dscore'),
-                                alpr_options.get('min_score')))
+                        .format(label, dscore, score, self.options.get('platerec_min_dscore'),
+                                self.options.get('platerec_min_score')))
 
         self.logger.Debug (2,'Exiting ALPR with labels:{}'.format(labels))
         return (bbox, labels, confs)
 
 
 class OpenAlpr(AlprBase):
-    def __init__(self, options={}, alpr_options={}, url=None, apikey=None, tempdir='/tmp'):
+    def __init__(self, options={}, tempdir='/tmp'):
         """Wrapper class for Open ALPR service
 
         Args:
             options (dict, optional): Various ALPR options. Defaults to {}.
-            alpr_options (dict, optional): Various ALPR options. Defaults to {}.
-            url (string, optional): URL for service. Defaults to None.
-            apikey (string, optional): API Key for service. Defaults to None.
             tempdir (str, optional): Temporary path to analyze image. Defaults to '/tmp'.
         """
-        AlprBase.__init__(self, url=url,options=options, alpr_options=alpr_options, apikey=apikey, tempdir=tempdir)
+        AlprBase.__init__(self, options=options, tempdir=tempdir)
         if not url:
             self.url = 'https://api.openalpr.com/v2/recognize'
 
         self.logger.Debug(
-            1,'Open ALPR initialized with options {} and url: {}'.
-            format(alpr_options, self.url))
-        self.alpr_options = alpr_options
-        self.options = options
+            1,'Open ALPR initialized with url: {}'.
+            format(self.url))
+        
 
     def detect(self, object):
         """Detection using OpenALPR
@@ -221,15 +248,15 @@ class OpenAlpr(AlprBase):
      
         with open(self.filename, 'rb') as fp:
             try:
-                alpr_options = self.alpr_options
+               
                 params = ''
-                if alpr_options.get('country'):
-                    params = params + '&country=' + alpr_options.get('country')
-                if alpr_options.get('state'):
-                    params = params + '&state=' + alpr_options.get('state')
-                if alpr_options.get('recognize_vehicle'):
+                if self.options.get('openalpr_country'):
+                    params = params + '&country=' + self.options.get('oenalpr_country')
+                if self.options.get('openalpr_state'):
+                    params = params + '&state=' + self.options.get('openalpr_state')
+                if self.options.get('openalpr_recognize_vehicle'):
                     params = params + '&recognize_vehicle=' + \
-                        str(alpr_options.get('recognize_vehicle'))
+                        str(self.options.get('openalpr_recognize_vehicle'))
 
                 rurl = '{}?secret_key={}{}'.format(self.url, self.apikey,
                                                    params)
@@ -260,10 +287,10 @@ class OpenAlpr(AlprBase):
             for plates in response.get('results'):
                 label = plates['plate']
                 conf = float(plates['confidence']) / 100
-                if conf < options.get('min_confidence'):
+                if conf < options.get('openalpr_min_confidence'):
                     self.logger.Debug(
                         1,'OpenALPR: discarding plate: {} because detected confidence {} is less than configured min confidence: {}'
-                        .format(label, conf, alpr_options.get('min_confidence')))
+                        .format(label, conf, self.options.get('openalpr_min_confidence')))
                     continue
 
                 if plates.get(
@@ -284,7 +311,7 @@ class OpenAlpr(AlprBase):
         return (bbox, labels, confs)
 
 class OpenAlprCmdLine(AlprBase):
-    def __init__(self, cmd=None, options={}, tempdir='/tmp'):
+    def __init__(self, options={}, tempdir='/tmp'):
         """Wrapper class for OpenALPR command line utility
 
         Args:
@@ -293,7 +320,10 @@ class OpenAlprCmdLine(AlprBase):
             tempdir (str, optional): Temporary path to analyze image. Defaults to '/tmp'.
         """        
         AlprBase.__init__(self, options=options, url='unused', apikey='unused', tempdir=tempdir)
-        self.options = options
+        
+        cmd=self.options.get('openalpr_cmdline_binary')
+
+                                                
         self.cmd = cmd + ' ' + self.options.get('openalpr_cmdline_params')
         if self.cmd.lower().find('-j') == -1:
             self.logger.Debug (2,'Adding -j to OpenALPR for json output')
@@ -329,16 +359,16 @@ class OpenAlprCmdLine(AlprBase):
         rescale = False
 
         if self.remove_temp:
-            os.remove(filename)
+            os.remove(self.filename)
 
         if response.get('results'):
             for plates in response.get('results'):
                 label = plates['plate']
                 conf = float(plates['confidence']) / 100
-                if conf < self.options.get('min_confidence'):
+                if conf < self.options.get('openalpr_cmdline_min_confidence'):
                     self.logger.Debug(
                         1,'OpenALPR cmd line: discarding plate: {} because detected confidence {} is less than configured min confidence: {}'
-                        .format(label, conf, options.get('min_confidence')))
+                        .format(label, conf, self.options.get('openalpr_cmdline_min_confidence')))
                     continue
                 
                 x1 = round(int(plates['coordinates'][0]['x']) * xfactor)
